"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStagedFiles = exports.getRootDir = exports.getDiffJsonPath = exports.getReportPath = exports.filterDiffFiles = exports.runEslintForDiff = void 0;
var child_process_1 = require("child_process");
var path_1 = __importDefault(require("path"));
var logger_1 = require("../utils/logger");
var cliArgsToObject_1 = require("../utils/cliArgsToObject");
var fileUtils_1 = require("../utils/fileUtils");
var getModifiedDiff_1 = require("./getModifiedDiff");
function runEslintForDiff(cliParams, options) {
    var _this = this;
    var _a = (0, cliArgsToObject_1.cliArgsToObject)(cliParams), diffPath = _a.diffPath, lintEnv = _a.lintEnv;
    var format = "json";
    var reportPath = getReportPath();
    var branchDiffJsonPath = getDiffJsonPath(diffPath);
    var diffJSON = (0, fileUtils_1.checkIfFileExists)(branchDiffJsonPath)
        ? require(diffPath)
        : null;
    var diffFiles = filterDiffFiles(diffJSON);
    var lintFiles = (0, fileUtils_1.checkIfFileExists)(getDiffJsonPath(diffPath))
        ? [path_1.default.resolve(process.cwd(), "uat")]
        : diffFiles;
    if (lintEnv === "pre-commit") {
        lintFiles = getStagedFiles();
    }
    return new Promise(function (resolve) {
        var command = [
            "eslint",
            lintFiles.join(" "),
            "--format=".concat(format),
            "-o",
            "".concat(reportPath),
        ];
        try {
            var lint_process = (0, child_process_1.spawn)("npx", command, {
                shell: true,
                cwd: process.cwd(),
            });
            lint_process.stdout.on("data", function (data) {
                logger_1.Logger.log(logger_1.Logger.INFO_TYPE, data);
            });
            lint_process.stderr.on("error", function (err) {
                logger_1.Logger.log(logger_1.Logger.FAILURE_TYPE, err);
            });
            lint_process.on("error", function (errors) {
                logger_1.Logger.log(logger_1.Logger.FAILURE_TYPE, errors);
            });
            lint_process.on("close", function (onclose) { return __awaiter(_this, void 0, void 0, function () {
                var filteredJson;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!(diffPath && (diffFiles.length !== 0))) return [3, 2];
                            return [4, filterReportBasedDiff(require(reportPath), diffJSON)];
                        case 1:
                            filteredJson = _a.sent();
                            (0, fileUtils_1.writeFileContents)(reportPath, JSON.stringify(filteredJson));
                            _a.label = 2;
                        case 2:
                            resolve({ status: "success" });
                            return [2];
                    }
                });
            }); });
        }
        catch (error) {
            logger_1.Logger.log(logger_1.Logger.INFO_TYPE, error);
            logger_1.Logger.log(logger_1.Logger.FAILURE_TYPE, "Execution Failed");
        }
    });
}
exports.runEslintForDiff = runEslintForDiff;
function filterReportBasedDiff(reportFilteredJSON, diffJson) {
    return new Promise(function (resolve) {
        if (!diffJson) {
            logger_1.Logger.log(logger_1.Logger.FAILURE_TYPE, "git diff json is not given ...");
            resolve([]);
        }
        var impactLineMap = filterDiffJson(diffJson);
        reportFilteredJSON = reportFilteredJSON.filter(function (result) {
            var isImpactFile = result.filePath;
            if (!isImpactFile || typeof isImpactFile !== "string") {
                return false;
            }
            if (isImpactFile.includes(".feature")) {
                return false;
            }
            var impactLines = impactLineMap.get(isImpactFile) || [];
            if (impactLines.length !== 0) {
                result.messages = result.messages.filter(function (errorMsg) {
                    return impactLines.includes(errorMsg.line);
                });
                return true;
            }
            return false;
        });
        resolve(reportFilteredJSON);
    });
}
function filterDiffJson(diffJson) {
    var _a;
    var diffFilesMap = new Map();
    (_a = diffJson === null || diffJson === void 0 ? void 0 : diffJson.diffs) === null || _a === void 0 ? void 0 : _a.forEach(function (diff) {
        var diffPathKey = path_1.default.resolve(getRootLintPath(), diff.new_path);
        if (diffPathKey === undefined) {
            return;
        }
        if (diffPathKey) {
            diffFilesMap.set(diffPathKey, (0, getModifiedDiff_1.getModifiedLines)(diff.diff).modifiedLines);
        }
    });
    return diffFilesMap;
}
function getRootDir() {
    return process.cwd();
}
exports.getRootDir = getRootDir;
function filterDiffFiles(diffJson) {
    if (!diffJson) {
        return [];
    }
    var rootPath = getRootLintPath();
    return diffJson === null || diffJson === void 0 ? void 0 : diffJson.diffs.map(function (diff) {
        return path_1.default.resolve(rootPath, diff === null || diff === void 0 ? void 0 : diff.new_path);
    });
}
exports.filterDiffFiles = filterDiffFiles;
function getReportPath(reportPath, reportOptions) {
    var jsonReportPath = reportPath ||
        path_1.default.resolve(process.cwd(), "uat", "lint-report", "lintReport.json");
    return jsonReportPath;
}
exports.getReportPath = getReportPath;
function getDiffJsonPath(diffJsonPath) {
    return path_1.default.resolve(diffJsonPath);
}
exports.getDiffJsonPath = getDiffJsonPath;
function getStagedFiles() {
    var command = "git diff --cached -U0 HEAD --name-only";
    var child = (0, child_process_1.spawnSync)(command, { shell: true });
    var diffFiles = child.stdout
        .toString()
        .split("\n")
        .map(function (filePath) { return path_1.default.resolve(getRootLintPath(), filePath); });
    diffFiles.pop();
    return diffFiles;
}
exports.getStagedFiles = getStagedFiles;
function getRootLintPath() {
    var childProcess = (0, child_process_1.spawnSync)("git", ["rev-parse", "--show-toplevel"], {
        shell: true,
    });
    return childProcess.stdout.toString().split("\n").filter(Boolean).pop();
}
//# sourceMappingURL=eslintLintStage.js.map