"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSonarProperties = exports.getSonarHostUrl = exports.getTestFiles = exports.getSourceFiles = exports.getProjectName = void 0;
var path_1 = __importDefault(require("path"));
var startServer_sonarQube_1 = require("./startServer-sonarQube");
var eslintLintStage_1 = require("./eslintLintStage");
var rootPath_1 = require("../utils/rootPath");
function getSonarHostUrl(cliArgument) {
    var sonarqube_host_url = "https://serverlinter-np.zohodesk.csez.zohocorpin.com/";
    return sonarqube_host_url;
}
exports.getSonarHostUrl = getSonarHostUrl;
function getProjectName(cliArgument) {
    var repo = cliArgument.repo, branch = cliArgument.branch, username = cliArgument.username, lintEnv = cliArgument.lintEnv;
    var project_name = repo && branch && username ? "".concat(repo, "_").concat(branch, "_").concat(username) : "UAT_Testing";
    if (lintEnv === "pre-commit") {
        project_name = "".concat((0, startServer_sonarQube_1.getProjectNameFrmGit)(), "_pre-commit");
    }
    return project_name;
}
exports.getProjectName = getProjectName;
function getTestFiles(cliArgument) {
    var _a;
    var _b = cliArgument.diffPath, diffPath = _b === void 0 ? false : _b;
    if (!diffPath && typeof diffPath === 'boolean') {
        return ["".concat(path_1.default.resolve(process.cwd(), "uat"))].join(",");
    }
    var testFiles = (_a = (0, startServer_sonarQube_1.filterSpecAndFeatureFiles)(getFilesBasedRunningEnv(cliArgument))) === null || _a === void 0 ? void 0 : _a.stepFilesPath;
    return testFiles.join(',');
}
exports.getTestFiles = getTestFiles;
function getSourceFiles(cliArgument) {
    var _a;
    var _b = cliArgument.diffPath, diffPath = _b === void 0 ? false : _b;
    if (!diffPath && typeof diffPath === 'boolean') {
        return [" "].join('');
    }
    var sourceFiles = (_a = (0, startServer_sonarQube_1.filterSpecAndFeatureFiles)(getFilesBasedRunningEnv(cliArgument))) === null || _a === void 0 ? void 0 : _a.featureFilesPath;
    return sourceFiles;
}
exports.getSourceFiles = getSourceFiles;
function getFilesBasedRunningEnv(cliArgument) {
    var lintEnv = cliArgument.lintEnv, diffPath = cliArgument.diffPath;
    if (lintEnv === 'pre-commit') {
        return (0, eslintLintStage_1.getStagedFiles)();
    }
    return (0, eslintLintStage_1.filterDiffFiles)(require((0, eslintLintStage_1.getDiffJsonPath)(diffPath)));
}
function getSonarProperties(cliObjects) {
    var sonarqube_host_url = "https://serverlinter-np.zohodesk.csez.zohocorpin.com/";
    var sonar_scanner_path = (0, rootPath_1.getSonarJarPath)();
    var _a = (0, startServer_sonarQube_1.getCredentials)((cliObjects.login = false), (cliObjects.password = false)), Dlogin = _a.Dlogin, Dpassword = _a.Dpassword;
    var project_name = getProjectName(cliObjects);
    var resultFilesPath = getTestFiles(cliObjects);
    var source_directories = getSourceFiles(cliObjects);
    var command = [
        "-jar",
        sonar_scanner_path,
        "-Dsonar.host.url=".concat(sonarqube_host_url),
        "-Dsonar.projectKey=".concat(project_name),
        "-Dsonar.login=".concat(Dlogin),
        "-Dsonar.password=".concat(Dpassword),
        "-Dsonar.sources=".concat(source_directories),
        "-Dsonar.tests=".concat(resultFilesPath),
        "-Dsonar.language=js",
        "-Dsonar.working.directory=".concat((0, startServer_sonarQube_1.getSonarArtifactsDir)()),
        "-Dsonar.eslint.reportPaths=".concat((0, eslintLintStage_1.getReportPath)()),
        "-Dsonar.javascript.lcov.reportPaths=coverage/lcov-report/lcov.info",
    ];
    return command;
}
exports.getSonarProperties = getSonarProperties;
//# sourceMappingURL=getSonarProperties.js.map