"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSonarArtifactsDir = exports.getCredentials = exports.filterSpecAndFeatureFiles = exports.getLintStatus = exports.runChildSyncProcess = exports.getProjectNameFrmGit = exports.runSonarAnalysis = void 0;
var path_1 = __importDefault(require("path"));
var child_process_1 = require("child_process");
var eslintLintStage_1 = require("./eslintLintStage");
var cliArgsToObject_1 = require("../utils/cliArgsToObject");
var sonarReportSummary_1 = require("./sonarReportSummary");
var logger_1 = require("../utils/logger");
var rootPath_1 = require("../utils/rootPath");
var popUpCli_1 = require("./popUpCli");
var getSonarProperties_1 = require("./getSonarProperties");
var fileUtils_1 = require("../utils/fileUtils");
function runSonarAnalysis(cliParams, executeArgs) {
    var _a, _b;
    var cliArguments = (0, cliArgsToObject_1.cliArgsToObject)(cliParams);
    var _c = cliArguments.lintEnv, lintEnv = _c === void 0 ? null : _c;
    var jsonReportPath = executeArgs.jsonReportPath, triggerFrom = executeArgs.triggerFrom;
    if (jsonReportPath && (0, fileUtils_1.checkIfFileExists)(jsonReportPath) && triggerFrom == 'pre-commit') {
        lintEnv = "pre-commit";
    }
    var sonarqube_host_url = "https://serverlinter-np.zohodesk.csez.zohocorpin.com/";
    var sonar_scanner_path = (0, rootPath_1.getSonarJarPath)();
    var _d = getCredentials((cliArguments.login = false), (cliArguments.password = false)), Dlogin = _d.Dlogin, Dpassword = _d.Dpassword;
    var project_name = (0, getSonarProperties_1.getProjectName)(cliArguments);
    var resultFilesPath = (0, getSonarProperties_1.getTestFiles)(cliArguments);
    var source_directories = (0, getSonarProperties_1.getSourceFiles)(cliArguments);
    var command = [
        "-jar",
        sonar_scanner_path,
        "-Dsonar.host.url=".concat(sonarqube_host_url),
        "-Dsonar.projectKey=".concat(project_name),
        "-Dsonar.login=".concat(Dlogin),
        "-Dsonar.password=".concat(Dpassword),
        "-Dsonar.sources=".concat(source_directories),
        "-Dsonar.tests=".concat(resultFilesPath),
        "-Dsonar.language=js",
        "-Dsonar.working.directory=".concat(getSonarArtifactsDir()),
        "-Dsonar.eslint.reportPaths=".concat((0, eslintLintStage_1.getReportPath)()),
        "-Dsonar.javascript.lcov.reportPaths=coverage/lcov-report/lcov.info",
    ];
    var child_process = (0, child_process_1.spawn)("java", command);
    (_a = child_process.stdout) === null || _a === void 0 ? void 0 : _a.on("data", function (data) {
        logger_1.Logger.log(logger_1.Logger.SUCCESS_TYPE, data);
    });
    (_b = child_process.stderr) === null || _b === void 0 ? void 0 : _b.on("data", function (errorOutput) {
        logger_1.Logger.log(logger_1.Logger.FAILURE_TYPE, errorOutput);
    });
    child_process.on("error", function (error) {
        logger_1.Logger.log(logger_1.Logger.FAILURE_TYPE, "Error: ".concat(error.message));
    });
    child_process.on("close", function (code) {
        logger_1.Logger.log(logger_1.Logger.INFO_TYPE, "Report to Server  Status - ".concat(code === 0 ? "Success" : "Failure"));
        (0, sonarReportSummary_1.writeSummaryOfLint)(cliParams);
        logger_1.Logger.log(logger_1.Logger.INFO_TYPE, "report url - ".concat((0, sonarReportSummary_1.getSummaryOfLint)(cliParams).reportUrl));
        if (lintEnv == "pre-commit") {
            logger_1.Logger.log(logger_1.Logger.SUCCESS_TYPE, "lint triggered from pre-commit ...");
            if (!getLintStatus().status && getLintStatus().message == "failed") {
                logger_1.Logger.log(logger_1.Logger.FAILURE_TYPE, "rules violated .. ");
                (0, popUpCli_1.showMsgPopUp)("IssueFound");
                process.exit(1);
            }
            else {
                (0, popUpCli_1.showMsgPopUp)("NoIssueFound");
            }
        }
    });
}
exports.runSonarAnalysis = runSonarAnalysis;
function filterSpecAndFeatureFiles(resultJson) {
    return resultJson.reduce(function (filesPath, fileReport) {
        if (fileReport.includes(".feature")) {
            filesPath.featureFilesPath.push(fileReport);
        }
        else {
            filesPath.stepFilesPath.push(fileReport);
        }
        return filesPath;
    }, { stepFilesPath: [], featureFilesPath: [] });
}
exports.filterSpecAndFeatureFiles = filterSpecAndFeatureFiles;
function getProjectNameFrmGit() {
    var $repoName = getRepoName();
    var $branchName = getBranchName();
    var $username = getGitUsername();
    return $repoName && $branchName && $username
        ? "".concat($repoName, "_").concat($branchName, "_").concat($username)
        : "desk_default_project";
}
exports.getProjectNameFrmGit = getProjectNameFrmGit;
function getGitUsername() {
    var userName = runChildSyncProcess("git", [
        "config",
        "user.email",
    ]);
    return userName.pop().split("@")[0];
}
function getRepoName() {
    var repoName = runChildSyncProcess("git", [
        "remote",
        "get-url",
        "origin",
    ]);
    return repoName.pop().split("/").pop().split(".")[0];
}
function getBranchName() {
    var branchName = runChildSyncProcess("git", [
        "rev-parse",
        "--abbrev-ref",
        "HEAD",
    ]);
    return branchName.shift().trim();
}
function runChildSyncProcess(command, params, directory) {
    var demon_process = (0, child_process_1.spawnSync)(command, params, {
        shell: true,
        cwd: directory,
    });
    return demon_process.stdout.toString().split("\n").filter(Boolean);
}
exports.runChildSyncProcess = runChildSyncProcess;
function getCredentials(login, password) {
    if (login && password) {
        return {
            Dlogin: login,
            Dpassword: password,
        };
    }
    return {
        Dlogin: "developer",
        Dpassword: "developer",
    };
}
exports.getCredentials = getCredentials;
function getLintStatus() {
    var reportStatus = true;
    var report = require((0, eslintLintStage_1.getReportPath)());
    if (report.length == 0) {
        reportStatus = true;
        return {
            status: true,
            message: "passed",
        };
    }
    if (report.length != 0) {
        for (var _i = 0, report_1 = report; _i < report_1.length; _i++) {
            var element = report_1[_i];
            if (element.messages != 0) {
                reportStatus = false;
                break;
            }
        }
        if (reportStatus) {
            return { status: reportStatus, message: "passed" };
        }
        return { status: reportStatus, message: "failed" };
    }
    return { status: reportStatus, message: "passed" };
}
exports.getLintStatus = getLintStatus;
function getSonarArtifactsDir() {
    return path_1.default.resolve(process.cwd(), "uat", "lint-report", ".scannerwork");
}
exports.getSonarArtifactsDir = getSonarArtifactsDir;
//# sourceMappingURL=startServer-sonarQube.js.map